@@ -1,22 +1,21 @@
 package Dist::Zilla::Plugin::ScpDeploy;
 BEGIN {
-  $Dist::Zilla::Plugin::ScpDeploy::VERSION = '1.20110709';
+  $Dist::Zilla::Plugin::ScpDeploy::VERSION = '20110610.2306';
 }
 # ABSTRACT: deploy via scp and ssh
 
-use Moose 2.0007;
+use Moose;
 use Moose::Util::TypeConstraints;
 
+use warnings;
 use namespace::autoclean;
-use constant HOSTSTYPE => __PACKAGE__ . '::Types::Hosts';
 
 with 'Dist::Zilla::Role::Releaser';
 
-subtype HOSTSTYPE, as 'ArrayRef[Str]';
-coerce  HOSTSTYPE, from 'Str', via { [ split /,\s*/, $_ ] };
+coerce 'ArrayRef[Str]', from 'Str', via { [ split /,\s*/, $_ ] };
 
-has [qw( remote_dir command )], is => 'ro', required => 1;
-has 'hosts', isa => HOSTSTYPE,  is => 'ro', required => 1, coerce => 1;
+has [qw( remote_dir command )],      is => 'ro', required => 1;
+has 'hosts', isa => 'ArrayRef[Str]', is => 'ro', required => 1, coerce => 1;
 
 sub release
 {
@@ -43,11 +42,11 @@ Dist::Zilla::Plugin::ScpDeploy - deploy via scp and ssh
 
 =head1 VERSION
 
-version 1.20110709
+version 20110610.2306
 
 =head1 DESCRIPTION
 
-This plugin can automatically deploy a release when you run C<dzil release>. It
+This plugin can automatically deploy a release when you run C<dist release>. It
 performs two actions for you:
 
 =over 4
@@ -76,7 +75,7 @@ to configure the remote hosts such that the remote directory and the remote
 command to run are available.
 
 The remote command receives one argument: the path to the release tarball in
-the given remote directory.
+the give remote directory.
 
 =head1 AUTHOR
 
